[![pypi](https://img.shields.io/pypi/v/lnschema_bionty?color=%2334D058&label=pypi%20package)](https://pypi.org/project/lnschema_bionty)

# lnschema-bionty: Biological entities (`zdno`)

Read the [docs](https://lamin.ai/docs/lnschema-biology).
